Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5844)

Unified Diff: chrome/browser/ui/views/frame/browser_view.h

Issue 2937993002: Revert of Fix stability and data racing issues, coalesce more updates for JumpList (Closed)
Patch Set: Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/ui/views/frame/browser_view.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/views/frame/browser_view.h
diff --git a/chrome/browser/ui/views/frame/browser_view.h b/chrome/browser/ui/views/frame/browser_view.h
index d340404551a223d83ad1229011a190aabb8e5da2..fd1e41763a1a4d80af3d4cf88b9df1a20b12538e 100644
--- a/chrome/browser/ui/views/frame/browser_view.h
+++ b/chrome/browser/ui/views/frame/browser_view.h
@@ -62,6 +62,10 @@
class ToolbarView;
class TopContainerView;
class WebContentsCloseHandler;
+
+#if defined(OS_WIN)
+class JumpList;
+#endif
namespace extensions {
class ActiveTabPermissionGranter;
@@ -493,8 +497,8 @@
// Callback for the loading animation(s) associated with this view.
void LoadingAnimationCallback();
// LoadCompleteListener::Delegate implementation. Creates the JumpList after
// the first page load.
void OnLoadCompleted() override;
// Returns the BrowserViewLayout.
@@ -683,6 +687,9 @@
#if defined(OS_WIN)
// Helper class to listen for completion of first page load.
std::unique_ptr<LoadCompleteListener> load_complete_listener_;
+
+ // The custom JumpList for Windows 7.
+ scoped_refptr<JumpList> jumplist_;
#endif
// The timer used to update frames for the Loading Animation.
« no previous file with comments | « no previous file | chrome/browser/ui/views/frame/browser_view.cc » ('j') | no next file with comments »
@@ -493,8 +497,8 @@
// Callback for the loading animation(s) associated with this view.
void LoadingAnimationCallback();
- // LoadCompleteListener::Delegate implementation. Creates the JumpList after
- // the first page load.
+ // LoadCompleteListener::Delegate implementation. Creates and initializes the
+ // |jumplist_| after the first page load.
void OnLoadCompleted() override;
// Returns the BrowserViewLayout.

Powered by Google App Engine
This is Rietveld 408576698